import { app } from '@/app.ts';
import { Prompt } from '@/models/prompt.ts';
import { chat } from '@/modules/ollama.ts';
import { CustomError } from '@abearxiong/router';
import { PromptTemplate } from '@kevisual/ai-graph';

app
  .route('ai', 'run', { nextRoute: { id: 'runOllama' } })
  .define({
    validator: {
      key: {
        type: 'string',
        required: true,
        message: 'Prompt key is required',
      },
    },
  })
  .define(async (ctx) => {
    // ctx.currentRoute?.verify(ctx, true);

    const { key, inputs = [] } = ctx.query.data || {};
    if (!key) {
      throw new CustomError('Prompt key is required');
    }
    const prompt = await Prompt.findOne({ where: { key } });
    if (!prompt) {
      throw new CustomError('Prompt not found');
    }
    const { presetData } = prompt;
    const { data, validator } = presetData || {};
    // const { inputs = [] } = data;
    // TODO: 获取validator和inputs的内容
    const promptTemplate = new PromptTemplate({
      prompt: data.prompt,
      inputVariables: inputs.map((item) => {
        return {
          key: item.key,
          value: item.value,
        };
      }),
      localVariables: [],
    });
    const result = await promptTemplate.getTemplate();
    ctx.state = {
      prompt: result,
    };
    ctx.body = result;
  })
  .addTo(app);

app
  .route('ai', 'runOllama', {
    id: 'runOllama',
  })
  .define(async (ctx) => {
    const prompt = ctx.state.prompt;
    if (!prompt) {
      throw new CustomError('Prompt not found');
    }
    console.log('prompt', typeof prompt, prompt);
    const res = await chat([
      {
        role: 'user',
        content: prompt,
      },
    ]);
    ctx.body = res;
  })
  .addTo(app);
